# Change Log
All notable changes to this project will be documented in this file.
This project adheres to [Semantic Versioning](http://semver.org/).

## 0.3.0 - 2017-10-13
- Add alternative method of access entities and options

## 0.2.0 - 2017-08-05
- Add DataFrame.fromPandas and DataFrame.toPandas

## 0.1.2 - 2017-08-04
- Improve DataFrame initialization
- Fix issue with stdout in jupyter notebooks

## 0.1.1 - 2017-07-30
- Fix issues with strings in Python 3.

## 0.1.0 - 2017-07-22
- Initial release.
